@@ -32,10 +32,10 @@ class GameView : public QGraphicsView
 {
     public:
         /** Constructor */
-        explicit GameView( QGraphicsScene* scene, QWidget* parent = 0 );
+        explicit GameView( QGraphicsScene* scene, QWidget* parent = nullptr );
     protected:
         /** Reimplemented for notifying game scene of the resize event */
-        virtual void resizeEvent( QResizeEvent *event );
+        void resizeEvent( QResizeEvent *event ) Q_DECL_OVERRIDE;
 };
 
 #endif // GAMEVIEW_H
